# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Module containing the patterns service implementation for v0."""

import grpc

from ansys.geometry.core.errors import protect_grpc

from ..base.conversions import (
    from_measurement_to_server_angle,
    from_measurement_to_server_length,
)
from ..base.patterns import GRPCPatternsService
from .conversions import build_grpc_id, from_line_to_grpc_line, from_unit_vector_to_grpc_direction


class GRPCPatternsServiceV0(GRPCPatternsService):  # pragma: no cover
    """Patterns service for gRPC communication with the Geometry server.

    This class provides methods to interact with the Geometry server's
    patterns service. It is specifically designed for the v0 version of the
    Geometry API.

    Parameters
    ----------
    channel : grpc.Channel
        The gRPC channel to the server.
    """

    @protect_grpc
    def __init__(self, channel: grpc.Channel):  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2_grpc import CommandsStub

        self.stub = CommandsStub(channel)

    @protect_grpc
    def create_linear_pattern(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2 import CreateLinearPatternRequest

        # Create the request - assumes all inputs are valid and of the proper type
        request = CreateLinearPatternRequest(
            selection=[build_grpc_id(id) for id in kwargs["selection_ids"]],
            linear_direction=build_grpc_id(kwargs["linear_direction_id"]),
            count_x=kwargs["count_x"],
            pitch_x=from_measurement_to_server_length(kwargs["pitch_x"]),
            two_dimensional=kwargs["two_dimensional"],
            count_y=kwargs["count_y"],
            pitch_y=(
                from_measurement_to_server_length(kwargs["pitch_y"]) if kwargs["pitch_y"] else None
            ),
        )

        # Call the gRPC service
        response = self.stub.CreateLinearPattern(request)

        # Return the response - formatted as a dictionary
        return {
            "success": response.result.success,
        }

    @protect_grpc
    def modify_linear_pattern(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2 import ModifyLinearPatternRequest

        # Create the request - assumes all inputs are valid and of the proper type
        request = ModifyLinearPatternRequest(
            selection=[build_grpc_id(id) for id in kwargs["selection_ids"]],
            count_x=kwargs["count_x"],
            pitch_x=from_measurement_to_server_length(kwargs["pitch_x"]),
            count_y=kwargs["count_y"],
            pitch_y=from_measurement_to_server_length(kwargs["pitch_y"]),
            new_seed_index=kwargs["new_seed_index"],
            old_seed_index=kwargs["old_seed_index"],
        )

        # Call the gRPC service
        response = self.stub.ModifyLinearPattern(request)

        # Return the response - formatted as a dictionary
        return {
            "success": response.result.success,
        }

    @protect_grpc
    def create_circular_pattern(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2 import CreateCircularPatternRequest

        from ansys.geometry.core.shapes.curves.line import Line

        # Create direction if not None
        radial_direction = (
            from_unit_vector_to_grpc_direction(kwargs["radial_direction"])
            if kwargs["radial_direction"] is not None
            else None
        )

        # Create linear pitch if not None
        linear_pitch = (
            from_measurement_to_server_length(kwargs["linear_pitch"])
            if kwargs["linear_pitch"]
            else None
        )

        # Create line if axis is a line object
        circular_axis, axis = None, None
        if isinstance(kwargs["circular_axis"], Line):
            axis = from_line_to_grpc_line(kwargs["circular_axis"])
        else:
            circular_axis = build_grpc_id(kwargs["circular_axis"])

        # Create the request - assumes all inputs are valid and of the proper type
        request = CreateCircularPatternRequest(
            selection=[build_grpc_id(id) for id in kwargs["selection_ids"]],
            circular_count=kwargs["circular_count"],
            circular_axis=circular_axis,
            circular_angle=from_measurement_to_server_angle(kwargs["circular_angle"]),
            two_dimensional=kwargs["two_dimensional"],
            linear_count=kwargs["linear_count"],
            linear_pitch=linear_pitch,
            radial_direction=radial_direction,
            axis=axis,
        )

        # Call the gRPC service
        response = self.stub.CreateCircularPattern(request)

        # Return the response - formatted as a dictionary
        return {
            "success": response.result.success,
        }

    @protect_grpc
    def modify_circular_pattern(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2 import ModifyCircularPatternRequest

        # Create the request - assumes all inputs are valid and of the proper type
        request = ModifyCircularPatternRequest(
            selection=[build_grpc_id(id) for id in kwargs["selection_ids"]],
            circular_count=kwargs["circular_count"],
            linear_count=kwargs["linear_count"],
            step_angle=from_measurement_to_server_angle(kwargs["step_angle"]),
            step_linear=from_measurement_to_server_length(kwargs["step_linear"]),
        )

        # Call the gRPC service
        response = self.stub.ModifyCircularPattern(request)

        # Return the response - formatted as a dictionary
        return {
            "success": response.result.success,
        }

    @protect_grpc
    def create_fill_pattern(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2 import CreateFillPatternRequest

        # Create the request - assumes all inputs are valid and of the proper type
        request = CreateFillPatternRequest(
            selection=[build_grpc_id(id) for id in kwargs["selection_ids"]],
            linear_direction=build_grpc_id(kwargs["linear_direction_id"]),
            fill_pattern_type=kwargs["fill_pattern_type"].value,
            margin=from_measurement_to_server_length(kwargs["margin"]),
            x_spacing=from_measurement_to_server_length(kwargs["x_spacing"]),
            y_spacing=from_measurement_to_server_length(kwargs["y_spacing"]),
            row_x_offset=from_measurement_to_server_length(kwargs["row_x_offset"]),
            row_y_offset=from_measurement_to_server_length(kwargs["row_y_offset"]),
            column_x_offset=from_measurement_to_server_length(kwargs["column_x_offset"]),
            column_y_offset=from_measurement_to_server_length(kwargs["column_y_offset"]),
        )

        # Call the gRPC service
        response = self.stub.CreateFillPattern(request)

        # Return the response - formatted as a dictionary
        return {
            "success": response.result.success,
        }

    @protect_grpc
    def update_fill_pattern(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.geometry.v0.commands_pb2 import PatternRequest

        # Create the request - assumes all inputs are valid and of the proper type
        request = PatternRequest(
            selection=[build_grpc_id(id) for id in kwargs["selection_ids"]],
        )

        # Call the gRPC service
        response = self.stub.UpdateFillPattern(request)

        # Return the response - formatted as a dictionary
        return {
            "success": response.result.success,
        }



# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Module containing the model tools service implementation for v1."""

import grpc

from ansys.geometry.core.errors import protect_grpc

from ..base.model_tools import GRPCModelToolsService
from .conversions import (
    build_grpc_id,
    from_length_to_grpc_quantity,
    serialize_tracked_command_response,
)


class GRPCModelToolsServiceV1(GRPCModelToolsService):
    """Model tools service for gRPC communication with the Geometry server.

    This class provides methods to interact with the Geometry server's
    model tools service. It is specifically designed for the v1 version of the
    Geometry API.

    Parameters
    ----------
    channel : grpc.Channel
        The gRPC channel to the server.
    """

    @protect_grpc
    def __init__(self, channel: grpc.Channel):  # noqa: D102
        from ansys.api.discovery.v1.operations.edit_pb2_grpc import EditStub
        from ansys.api.discovery.v1.operations.sketch_pb2_grpc import SketchStub

        self.stub = EditStub(channel)
        self.sketch_stub = SketchStub(channel)

    @protect_grpc
    def chamfer(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.discovery.v1.operations.edit_pb2 import ChamferRequest, ChamferRequestData

        # Create the request - assumes all inputs are valid and of the proper type
        request = ChamferRequest(
            request_data=[
                ChamferRequestData(
                    ids=[build_grpc_id(id) for id in kwargs["selection_ids"]],
                    distance=from_length_to_grpc_quantity(kwargs["distance"]),
                )
            ]
        )

        # Call the gRPC service
        response = self.stub.Chamfer(request).response_data[0]

        # Return the response as a dictionary
        return {
            "success": response.success,
        }

    @protect_grpc
    def fillet(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.discovery.v1.operations.edit_pb2 import FilletRequest, FilletRequestData

        # Create the request - assumes all inputs are valid and of the proper type
        request = FilletRequest(
            request_data=[
                FilletRequestData(
                    ids=[build_grpc_id(id) for id in kwargs["selection_ids"]],
                    radius=from_length_to_grpc_quantity(kwargs["radius"]),
                )
            ]
        )

        # Call the gRPC service and serialize the response
        response = self.stub.Fillet(request)
        tracked_response = serialize_tracked_command_response(response.tracked_command_response)

        # Return the response as a dictionary
        return {
            "success": tracked_response.get("success"),
        }

    @protect_grpc
    def full_fillet(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.discovery.v1.operations.edit_pb2 import FullFilletRequest

        # Create the request - assumes all inputs are valid and of the proper type
        request = FullFilletRequest(
            face_ids=[build_grpc_id(id) for id in kwargs["selection_ids"]],
        )

        # Call the gRPC service and serialize the response
        response = self.stub.FullFillet(request)
        tracked_response = serialize_tracked_command_response(response.tracked_command_response)

        # Return the response as a dictionary
        return {
            "success": tracked_response.get("success"),
        }

    @protect_grpc
    def move_rotate(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.discovery.v1.operations.edit_pb2 import (
            MoveRotateRequest,
            MoveRotateRequestData,
        )

        from .conversions import from_angle_to_grpc_quantity, from_line_to_grpc_line

        # Create the request - assumes all inputs are valid and of the proper type
        request = MoveRotateRequest(
            request_data=[
                MoveRotateRequestData(
                    selection_ids=[build_grpc_id(kwargs["selection_id"])],
                    axis=from_line_to_grpc_line(kwargs["axis"]),
                    angle=from_angle_to_grpc_quantity(kwargs["angle"]),
                )
            ]
        )

        # Call the gRPC service and serialize the response
        response = self.stub.MoveRotate(request)
        tracked_response = serialize_tracked_command_response(response.tracked_command_response)

        # Return the response as a dictionary
        return {
            "success": tracked_response.get("success"),
            "modified_bodies": [
                body.get("id").id for body in tracked_response.get("modified_bodies")
            ],
            "modified_faces": [
                face.get("id").id for face in tracked_response.get("modified_faces")
            ],
            "modified_edges": [
                edge.get("id").id for edge in tracked_response.get("modified_edges")
            ],
        }

    @protect_grpc
    def move_translate(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.discovery.v1.operations.edit_pb2 import (
            MoveTranslateRequest,
            MoveTranslateRequestData,
        )

        from .conversions import from_unit_vector_to_grpc_direction

        # Create the request - assumes all inputs are valid and of the proper type
        request = MoveTranslateRequest(
            request_data=[
                MoveTranslateRequestData(
                    selection_ids=[build_grpc_id(kwargs["selection_id"])],
                    direction=from_unit_vector_to_grpc_direction(kwargs["direction"]),
                    distance=from_length_to_grpc_quantity(kwargs["distance"]),
                )
            ]
        )
        # Call the gRPC service and serialize the response
        response = self.stub.MoveTranslate(request)
        tracked_response = serialize_tracked_command_response(response.tracked_command_response)

        # Return the response as a dictionary
        return {
            "success": tracked_response.get("success"),
        }

    @protect_grpc
    def create_sketch_line(self, **kwargs) -> dict:  # noqa: D102
        from ansys.api.discovery.v1.operations.sketch_pb2 import (
            CreateSketchLineRequest,
            CreateSketchLineRequestData,
        )

        from .conversions import from_point3d_to_grpc_point

        # Create the request - assumes all inputs are valid and of the proper type
        request = CreateSketchLineRequest(
            request_data=[
                CreateSketchLineRequestData(
                    point1=from_point3d_to_grpc_point(kwargs["start"]),
                    point2=from_point3d_to_grpc_point(kwargs["end"]),
                )
            ]
        )

        # Call the gRPC service
        _ = self.sketch_stub.CreateSketchLine(request)

        # Return the response - formatted as a dictionary
        return {}



# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Module containing the repair tools service implementation for v1."""

import grpc

from ansys.geometry.core.errors import protect_grpc

from ..base.repair_tools import GRPCRepairToolsService


class GRPCRepairToolsServiceV1(GRPCRepairToolsService):  # pragma: no cover
    """Repair tools service for gRPC communication with the Geometry server.

    Parameters
    ----------
    channel : grpc.Channel
        The gRPC channel to the server.
    """

    @protect_grpc
    def __init__(self, channel: grpc.Channel):  # noqa: D102
        from ansys.api.geometry.v1.repairtools_pb2_grpc import RepairToolsStub

        self.stub = RepairToolsStub(channel)

    @protect_grpc
    def find_split_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_extra_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_inexact_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_short_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_duplicate_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_missing_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_small_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_stitch_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_simplify(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_interferences(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_and_fix_short_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_and_fix_extra_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_and_fix_split_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_and_fix_simplify(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_and_fix_stitch_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def inspect_geometry(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def repair_geometry(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_duplicate_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_missing_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_inexact_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_extra_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_short_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_small_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_split_edges(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_stitch_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_unsimplified_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def fix_interference(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError



# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Module containing the designs service implementation for v1."""

import grpc

from ansys.geometry.core.errors import protect_grpc

from ..base.designs import GRPCDesignsService


class GRPCDesignsServiceV1(GRPCDesignsService):  # pragma: no cover
    """Designs service for gRPC communication with the Geometry server.

    This class provides methods to interact with the Geometry server's
    designs service. It is specifically designed for the v1 version of the
    Geometry API.

    Parameters
    ----------
    channel : grpc.Channel
        The gRPC channel to the server.
    """

    @protect_grpc
    def __init__(self, channel: grpc.Channel):  # noqa: D102
        from ansys.api.dbu.v1.designs_pb2_grpc import DesignsStub

        self.stub = DesignsStub(channel)

    @protect_grpc
    def open(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def new(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def get_assembly(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def close(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def put_active(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def save_as(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def download_export(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def stream_download_export(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def insert(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def get_active(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def upload_file(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def upload_file_stream(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def stream_design_tessellation(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def download_file(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError



# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Module containing the Prepare Tools service implementation for v1."""

import grpc

from ansys.geometry.core.errors import protect_grpc

from ..base.prepare_tools import GRPCPrepareToolsService


class GRPCPrepareToolsServiceV1(GRPCPrepareToolsService):  # pragma: no cover
    """Prepare tools service for gRPC communication with the Geometry server.

    This class provides methods to interact with the Geometry server's
    Prepare Tools service. It is specifically designed for the v1 version
    of the Geometry API.

    Parameters
    ----------
    channel : grpc.Channel
        The gRPC channel to the server.
    """

    @protect_grpc
    def __init__(self, channel: grpc.Channel):  # noqa: D102
        from ansys.api.geometry.v1.preparetools_pb2_grpc import PrepareToolsStub

        self.stub = PrepareToolsStub(channel)

    @protect_grpc
    def extract_volume_from_faces(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def extract_volume_from_edge_loops(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def remove_rounds(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def share_topology(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def enhanced_share_topology(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_logos(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def find_and_remove_logos(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def remove_logo(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def detect_helixes(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def create_box_enclosure(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def create_cylinder_enclosure(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def create_sphere_enclosure(self, **kwargs) -> dict:  # noqa: D102
        raise NotImplementedError

    @protect_grpc
    def detect_sweepable_bodies(self, **kwargs):  # noqa: D102
        raise NotImplementedError
